pub struct ConditionalProfiler { /* private fields */ }Expand description
Conditional profiling based on feature flags or runtime conditions
Implementations
Sourceimpl ConditionalProfiler
impl ConditionalProfiler
Sourcepub fn debug_only() -> Self
pub fn debug_only() -> Self
Create a conditional profiler that only profiles in debug mode
Sourcepub fn env_var(var_name: &str) -> Self
pub fn env_var(var_name: &str) -> Self
Create a conditional profiler based on an environment variable
Sourcepub fn feature_flag(feature: &str) -> Self
pub fn feature_flag(feature: &str) -> Self
Create a conditional profiler based on a feature flag